import qs from 'querystring'
import { withHandlers } from 'recompose'

const createAnchorElement = (file, filename) => {
  const url = URL.createObjectURL(file)
  const a = document.createElement('a')

  a.href = url
  a.download = filename
  document.body.appendChild(a)

  return {
    a,
    url,
  }
}

const removeAnchorElement = (a, url) => {
  document.body.removeChild(a)
  URL.revokeObjectURL(url)
}

export default withHandlers({
  downloadFile: () => ({ fileId, token, fileName = 'file' }) => {
    if (!token) return

    const fileURL = `${
      window.location.origin
    }/api/files/${fileId}?${qs.stringify({
      download: true,
    })}`

    const xhr = new XMLHttpRequest()
    xhr.onreadystatechange = function onXhrStateChange() {
      if (this.readyState === 4) {
        if (this.status >= 200 && this.status < 300) {
          const f = new File([this.response], fileName)

          const { a, url } = createAnchorElement(f, fileName)
          a.click()
          removeAnchorElement(a, url)
        }
      }
    }
    xhr.open('GET', fileURL)
    xhr.responseType = 'blob'
    xhr.setRequestHeader('Authorization', `Bearer ${token}`)
    xhr.send()
  },
})
