import React from 'react'
import { Button } from '@pubsweet/ui'
import styled from 'styled-components'
import { reduxForm } from 'redux-form'
import { th } from '@pubsweet/ui-toolkit'
import { compose, withProps } from 'recompose'
import { onSubmitUser as onSubmit } from '../utils'

import EditUserForm from '../Admin/EditUserForm'

const AccountDetailsEdit = ({ journal, user, setEditMode, handleSubmit }) => (
  <Root onSubmit={handleSubmit}>
    <EditUserForm journal={journal} title="Edit account details" user={user} />
    <Row>
      <Button onClick={setEditMode(false)}>Cancel</Button>
      <Button primary type="submit">
        Save
      </Button>
    </Row>
  </Root>
)

export default compose(
  withProps(({ user }) => ({ initialValues: user })),
  reduxForm({
    form: 'userManagement',
    onSubmit,
  }),
)(AccountDetailsEdit)

// #region styles
const Root = styled.form`
  background-color: ${th('colorBackground')};
  padding: ${th('gridUnit')};
  border: ${th('borderDefault')};
`

const Row = styled.div`
  align-items: flex-start;
  display: flex;
  flex-direction: row;
  justify-content: ${({ justify }) => justify || 'space-evenly'};
`
// #endregion
