import React from 'react'
import { connect } from 'react-redux'
import styled from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'
import { actions } from 'pubsweet-client'
import { withJournal } from 'xpub-journal'
import { withRouter } from 'react-router-dom'
import { compose, withHandlers } from 'recompose'
import {
  Logo,
  AppBar,
  AppBarMenu,
  AutosaveIndicator,
} from 'pubsweet-component-faraday-ui'

const App = ({ autosave, journal, goTo, children, logout, currentUser }) => (
  <Root className="faraday-root">
    <AppBar
      autosave={() => <AutosaveIndicator autosave={autosave} delay={4000} />}
      journal={journal}
      logo={() => (
        <Logo
          onClick={() => goTo('/')}
          src={journal.metadata.logo}
          title="Hindawi"
        />
      )}
      menu={() => (
        <AppBarMenu currentUser={currentUser} goTo={goTo} logout={logout} />
      )}
    />
    <MainContainer className="faraday-main">{children}</MainContainer>
  </Root>
)

export default compose(
  connect(
    state => ({
      autosave: state.autosave,
      currentUser: state.currentUser,
    }),
    { logout: actions.logoutUser },
  ),
  withJournal,
  withRouter,
  withHandlers({
    goTo: ({ history }) => path => {
      history.push(path)
    },
  }),
)(App)

// #region styles
const Root = styled.div`
  height: 100%;
  overflow-y: auto;
  div[open] {
    width: auto;
  }
`

const MainContainer = styled.div`
  display: flex;
  flex-direction: column;
  overflow-y: auto;
  padding: 0 calc(${th('gridUnit')} * 17);
  padding-top: calc(${th('appBar.height')} + ${th('gridUnit')} * 3 )};
`
// #endregion
